.. all-saltext.transactional-update.modules:

_________________
Execution Modules
_________________

.. currentmodule:: saltext.transactional_update.modules

.. autosummary::
    :toctree:

    transactional_update
